@@ -69,6 +69,7 @@ from naff.models import (
     InteractionCommand,
     SlashCommand,
     OptionTypes,
+    HybridCommand,
     PrefixedCommand,
     BaseCommand,
     to_snowflake,
@@ -78,6 +79,7 @@ from naff.models import (
     ModalContext,
     PrefixedContext,
     AutocompleteContext,
+    HybridContext,
     ComponentCommand,
     Context,
     application_commands_to_dict,
@@ -95,6 +97,7 @@ from naff.models.discord.modal import Modal
 from naff.models.naff.active_voice_state import ActiveVoiceState
 from naff.models.naff.application_commands import ModalCommand
 from naff.models.naff.auto_defer import AutoDefer
+from naff.models.naff.hybrid_commands import _prefixed_from_slash, _base_subcommand_generator
 from naff.models.naff.listener import Listener
 from naff.models.naff.tasks import Task
 
@@ -215,6 +218,7 @@ class Client(
         component_context: Type[ComponentContext]: The object to instantiate for Component Context
         autocomplete_context: Type[AutocompleteContext]: The object to instantiate for Autocomplete Context
         modal_context: Type[ModalContext]: The object to instantiate for Modal Context
+        hybrid_context: Type[HybridContext]: The object to instantiate for Hybrid Context
 
         global_pre_run_callback: Callable[..., Coroutine]: A coroutine to run before every command is executed
         global_post_run_callback: Callable[..., Coroutine]: A coroutine to run after every command is executed
@@ -259,6 +263,7 @@ class Client(
         owner_ids: Iterable["Snowflake_Type"] = (),
         modal_context: Type[ModalContext] = ModalContext,
         prefixed_context: Type[PrefixedContext] = PrefixedContext,
+        hybrid_context: Type[HybridContext] = HybridContext,
         send_command_tracebacks: bool = True,
         shard_id: int = 0,
         status: Status = Status.ONLINE,
@@ -317,6 +322,8 @@ class Client(
         """The object to instantiate for Autocomplete Context"""
         self.modal_context: Type[ModalContext] = modal_context
         """The object to instantiate for Modal Context"""
+        self.hybrid_context: Type[HybridContext] = hybrid_context
+        """The object to instantiate for Hybrid Context"""
 
         # flags
         self._ready = asyncio.Event()
@@ -488,6 +495,7 @@ class Client(
             self.component_context: ComponentContext,
             self.autocomplete_context: AutocompleteContext,
             self.modal_context: ModalContext,
+            self.hybrid_context: HybridContext,
         }
         for obj, expected in contexts.items():
             if not issubclass(obj, expected):
@@ -729,13 +737,6 @@ class Client(
             while True:
                 try:  # wait to let guilds cache
                     await asyncio.wait_for(self._guild_event.wait(), self.guild_event_timeout)
-                    if self.fetch_members:
-                        # ensure all guilds have completed chunking
-                        for guild in self.guilds:
-                            if guild and not guild.chunked.is_set():
-                                logger.debug(f"Waiting for {guild.id} to chunk")
-                                await guild.chunked.wait()
-
                 except asyncio.TimeoutError:
                     logger.warning("Timeout waiting for guilds cache: Not all guilds will be in cache")
                     break
@@ -1105,6 +1106,43 @@ class Client(
 
         return True
 
+    def add_hybrid_command(self, command: HybridCommand) -> bool:
+        if self.debug_scope:
+            command.scopes = [self.debug_scope]
+
+        if command.callback is None:
+            return False
+
+        if command.is_subcommand:
+            prefixed_base = self.prefixed_commands.get(str(command.name))
+            if not prefixed_base:
+                prefixed_base = _base_subcommand_generator(
+                    str(command.name), list(command.name.to_locale_dict().values()), str(command.description)
+                )
+                self.add_prefixed_command(prefixed_base)
+
+            if command.group_name:  # if this is a group command
+                _prefixed_cmd = prefixed_base
+                prefixed_base = prefixed_base.subcommands.get(str(command.group_name))
+
+                if not prefixed_base:
+                    prefixed_base = _base_subcommand_generator(
+                        str(command.group_name),
+                        list(command.group_name.to_locale_dict().values()),
+                        str(command.group_description),
+                        group=True,
+                    )
+                    _prefixed_cmd.add_command(prefixed_base)
+
+            new_command = _prefixed_from_slash(command)
+            new_command._parse_parameters()
+            prefixed_base.add_command(new_command)
+        else:
+            new_command = _prefixed_from_slash(command)
+            self.add_prefixed_command(new_command)
+
+        return self.add_interaction(command)
+
     def add_prefixed_command(self, command: PrefixedCommand) -> None:
         """
         Add a prefixed command to the client.
@@ -1175,6 +1213,8 @@ class Client(
                     self.add_modal_callback(func)
                 elif isinstance(func, ComponentCommand):
                     self.add_component_callback(func)
+                elif isinstance(func, HybridCommand):
+                    self.add_hybrid_command(func)
                 elif isinstance(func, InteractionCommand):
                     self.add_interaction(func)
                 elif (
